@@ -35,7 +35,7 @@ class AuthenticateUserCommand(AbstractCommand):
             verb=RequestVerb.POST,
             url=f"{demand_env_var(name='ACCESS_AUTH_ENDPOINT')}/v1/auth/token",
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
-            data=request.dict(),
+            data=request.dict(by_alias=True),
         )
         response: dict = self.wrapped_request(request=request)
         return Token.parse_obj(response)
